@@ -55,7 +55,7 @@ class SolarUtil:
     # 日期对应的非正式节日
     OTHER_FESTIVAL = {
         "1-8": ["周恩来逝世纪念日"],
-        "1-10": ["中国公安110宣传日"],
+        "1-10": ["中国人民警察节", "中国公安110宣传日"],
         "1-21": ["列宁逝世纪念日"],
         "1-26": ["国际海关日"],
         "2-2": ["世界湿地日"],
